*
* $Id: hcfast.inc,v 1.1.1.1 1996/01/16 17:07:50 mclareni Exp $
*
* $Log: hcfast.inc,v $
* Revision 1.1.1.1  1996/01/16 17:07:50  mclareni
* First import
*
*
#ifndef CERNLIB_HBOOK_HCFAST_INC
#define CERNLIB_HBOOK_HCFAST_INC
*
*
* hcfast.inc
*
*CMZ :  4.21/08 14/02/94  17.19.04  by  Rene Brun
*-- Author :    Rene Brun   14/02/94
      PARAMETER (NIDMAX=1000)
      COMMON/HCFAST/NID(NIDMAX)
 

#endif
